from typing import Dict

from resend import request


class Domains:
    """Domains API Wrapper"""

    @classmethod
    # https://resend.com/docs/api-reference/domains/create-domain
    def create(cls, params={}) -> Dict:
        path = "/domains"
        return request.Request(path=path, params=params, verb="post").perform()

    @classmethod
    # https://resend.com/docs/api-reference/domains/get-domain
    def get(cls, domain_id="") -> Dict:
        path = f"/domains/{domain_id}"
        return request.Request(path=path, params={}, verb="get").perform()

    @classmethod
    # https://resend.com/docs/api-reference/domains/list-domains
    def list(cls) -> Dict:
        path = "/domains"
        return request.Request(path=path, params={}, verb="get").perform()

    @classmethod
    # https://resend.com/docs/api-reference/domains/delete-domain
    def remove(cls, domain_id="") -> Dict:
        path = f"/domains/{domain_id}"
        return request.Request(path=path, params={}, verb="delete").perform()

    @classmethod
    # https://resend.com/docs/api-reference/domains/verify-domain
    def verify(cls, domain_id="") -> Dict:
        path = f"/domains/{domain_id}/verify"
        return request.Request(path=path, params={}, verb="post").perform()



from typing import Dict

from resend import request


class ApiKeys:
    """Api Keys API Wrapper"""

    @classmethod
    # https://resend.com/docs/api-reference/api-keys/create-api-key
    def create(cls, params={}) -> Dict:
        path = "/api-keys"
        return request.Request(path=path, params=params, verb="post").perform()

    @classmethod
    # https://resend.com/docs/api-reference/api-keys/list-api-keys
    def list(cls) -> Dict:
        path = "/api-keys"
        return request.Request(path=path, params={}, verb="get").perform()

    @classmethod
    # https://resend.com/docs/api-reference/api-keys/delete-api-key
    def remove(cls, api_key_id="") -> Dict:
        path = f"/api-keys/{api_key_id}"
        return request.Request(path=path, params={}, verb="delete").perform()



import os

from .api import Resend
from .api_keys import ApiKeys
from .domains import Domains
from .emails import Emails
from .request import Request
from .version import get_version

# Config vars
api_key = os.environ.get("RESEND_API_KEY")

# API resources
from .emails import Emails  # noqa

__all__ = ["get_version", "Resend", "Request", "Emails", "ApiKeys", "Domains"]



from warnings import warn
from typing import Dict, List

import resend


class Resend:
    def __init__(self, api_key: str):
        if not api_key:
            raise ValueError("Resend API Key is required.")
        resend.api_key = api_key

    def send_email(
        self,
        sender: str,
        to,
        subject: str,
        bcc=None,
        cc=None,
        reply_to=None,
        html: str = None,
        text: str = None,
        attachments: List[Dict] = None,
        tags: List[Dict] = None,
    ):
        warn(
            "[DEPRECATION]: method `send_email` is deprecated. Use resend.Emails.send() instead",
            DeprecationWarning)
        return resend.Emails.send(
            {
                "from": sender,
                "to": to,
                "subject": subject,
                "bcc": bcc,
                "cc": cc,
                "reply_to": reply_to,
                "html": html,
                "text": text,
                "attachments": attachments,
                "tags": tags,
            }
        )
